#ifndef __STRINGS_LOADED
#define __STRINGS_LOADED 1
#if __VMS_VER >= 70000000  /* Supported beginning in OpenVMS V7.0 */
/****************************************************************************
**
**  <strings.h> - String Handling
**
*****************************************************************************
**  Header introduced by the X/Open CAE Specification, Issue 4, Version 2
*****************************************************************************
**
**  Copyright Digital Equipment Corporation 1993, 1995. All rights reserved.
**
**  Restricted Rights: Use, duplication, or disclosure by the U.S.
**  Government is subject to restrictions as set forth in subparagraph
**  (c) (1) (ii) of DFARS 252.227-7013, or in FAR 52.227-19, or in FAR
**  52.227-14 Alt. III, as applicable.
**
**  This software is proprietary to and embodies the confidential
**  technology of Digital Equipment Corporation. Possession, use, or
**  copying of this software and media is authorized only pursuant to a
**  valid written license from Digital or an authorized sublicensor.
**
******************************************************************************
*/

#pragma __nostandard

/*
** Set up feature test macros
*/
# if defined _XOPEN_SOURCE_EXTENDED && !defined _XOPEN_SOURCE
#   define _XOPEN_SOURCE
# endif

# if defined _XOPEN_SOURCE && _POSIX_C_SOURCE < 2
#   undef  _POSIX_C_SOURCE
#   define _POSIX_C_SOURCE      2
# endif

# if defined _POSIX_SOURCE && _POSIX_C_SOURCE < 1
#   undef  _POSIX_C_SOURCE	    /* _POSIX_SOURCE obsolete.   */
#   define _POSIX_C_SOURCE	1   /* #define _POSIX_C_SOURCE 1 instead */
# endif

# if defined _POSIX_C_SOURCE && !defined _ANSI_C_SOURCE
#   define _ANSI_C_SOURCE
# endif 

# if defined __HIDE_FORBIDDEN_NAMES && !defined _ANSI_C_SOURCE
#   define _ANSI_C_SOURCE
# endif


#ifdef __cplusplus
    extern "C" {
#endif


/*
**  All declarations in this header file support 64 bit addresses
*/
#if __INITIAL_POINTER_SIZE
#   if (__VMS_VER < 70000000) || !defined __ALPHA
#      error " Pointer size usage not permitted before OpenVMS Alpha V7.0"
#   endif
#   pragma __pointer_size __save
#   pragma __pointer_size 64
#endif


/*
**  Create 'public' typedefs, structure definitions, and definitions which are
**  in this header file which are either not sensitive to pointer size or are
**  required to be short pointers.
*/
#ifndef __SIZE_T
#   define __SIZE_T 1
    typedef unsigned int size_t;
#endif


/*
**  X/Open extended definitions which accept 32 or 64 bit pointers
*/
int  bcmp  (const void * __s1, const void * __s2, size_t __n);
void (bcopy) (const void * __s1, void * __s2, size_t __n);
void (bzero) (void * __s1, size_t __n);
int  ffs   (int);

int  strcasecmp  (const char *, const char *);
int  strncasecmp (const char *, const char *, size_t);


/*
**  The following functions have interfaces of XXX, _XXX32, and _XXX64 due only
**  to the fact that the return argument is a pointer that is relative to one
**  of the arguments.
*/
#if __INITIAL_POINTER_SIZE == 32
#pragma __pointer_size 32
#endif

char *index  (const char *, int);
char *rindex (const char *, int);

#if __INITIAL_POINTER_SIZE == 32
#pragma __pointer_size 64
#endif


/*	 
**  DEC C extensions (64-bit interfaces are extensions)
*/	 
#if __INITIAL_POINTER_SIZE && !defined _XOPEN_SOURCE_EXTENDED
#   pragma __pointer_size 32
    char *_index32  (const char *, int);
    char *_rindex32 (const char *, int);
#   pragma __pointer_size 64
    char *_index64  (const char *, int);
    char *_rindex64 (const char *, int);
#endif


/*
**  DEC C Performance (Builtins)
**
**  Certain DEC C functions are available as compiler builtins.  Using
**  the builtins offer performance improvements and are enabled here
**  for all programs including this header file.
*/
#if defined(__ALPHA)

#   if __INITIAL_POINTER_SIZE == 32
#	pragma __pointer_size 32
#   endif

    void *__MEMMOVE (void *__s1, const void *__s2, size_t __n);
    void *__MEMSET  (void *__s, int __c, size_t __n);

#   define bcopy(__x, __y, __z) __MEMMOVE(__y, __x, __z) 
#   define bzero(__x, __y)      __MEMSET(__x, 0, __y) 

#endif


/*
**  Restore the users pointer context
*/
#if __INITIAL_POINTER_SIZE 
#   pragma __pointer_size __restore
#endif

#ifdef __cplusplus
    }
#endif

#pragma __standard
#endif  /* OpenVMS V7.0 */
#endif  /* __STRINGS_LOADED */
